==> pulumi-azure-native-kotlin-2.30.0.0-sources.jar: com/pulumi/azurenative/notificationhubs/kotlin/inputs/NamespacePropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.notificationhubs.kotlin.inputs

import com.pulumi.azurenative.notificationhubs.inputs.NamespacePropertiesArgs.builder
import com.pulumi.azurenative.notificationhubs.kotlin.enums.NamespaceStatus
import com.pulumi.azurenative.notificationhubs.kotlin.enums.NamespaceType
import com.pulumi.azurenative.notificationhubs.kotlin.enums.OperationProvisioningState
import com.pulumi.azurenative.notificationhubs.kotlin.enums.PublicNetworkAccess
import com.pulumi.azurenative.notificationhubs.kotlin.enums.ReplicationRegion
import com.pulumi.azurenative.notificationhubs.kotlin.enums.ZoneRedundancyPreference
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Represents namespace properties.
 * @property dataCenter Deprecated.
 * @property namespaceType Defines values for NamespaceType.
 * @property networkAcls A collection of network authorization rules.
 * @property pnsCredentials Collection of Notification Hub or Notification Hub Namespace PNS credentials.
 * @property provisioningState Defines values for OperationProvisioningState.
 * @property publicNetworkAccess Type of public network access.
 * @property replicationRegion Allowed replication region
 * @property scaleUnit Gets or sets scaleUnit where the namespace gets created
 * @property status Namespace status.
 * @property zoneRedundancy Namespace SKU name.
 */
public data class NamespacePropertiesArgs(
    public val dataCenter: Output<String>? = null,
    public val namespaceType: Output<Either<String, NamespaceType>>? = null,
    public val networkAcls: Output<NetworkAclsArgs>? = null,
    public val pnsCredentials: Output<PnsCredentialsArgs>? = null,
    public val provisioningState: Output<Either<String, OperationProvisioningState>>? = null,
    public val publicNetworkAccess: Output<Either<String, PublicNetworkAccess>>? = null,
    public val replicationRegion: Output<Either<String, ReplicationRegion>>? = null,
    public val scaleUnit: Output<String>? = null,
    public val status: Output<Either<String, NamespaceStatus>>? = null,
    public val zoneRedundancy: Output<Either<String, ZoneRedundancyPreference>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.notificationhubs.inputs.NamespacePropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.notificationhubs.inputs.NamespacePropertiesArgs =
        com.pulumi.azurenative.notificationhubs.inputs.NamespacePropertiesArgs.builder()
            .dataCenter(dataCenter?.applyValue({ args0 -> args0 }))
            .namespaceType(
                namespaceType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .networkAcls(networkAcls?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .pnsCredentials(pnsCredentials?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .provisioningState(
                provisioningState?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .publicNetworkAccess(
                publicNetworkAccess?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .replicationRegion(
                replicationRegion?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .scaleUnit(scaleUnit?.applyValue({ args0 -> args0 }))
            .status(
                status?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .zoneRedundancy(
                zoneRedundancy?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [NamespacePropertiesArgs].
 */
@PulumiTagMarker
public class NamespacePropertiesArgsBuilder internal constructor() {
    private var dataCenter: Output<String>? = null

    private var namespaceType: Output<Either<String, NamespaceType>>? = null

    private var networkAcls: Output<NetworkAclsArgs>? = null

    private var pnsCredentials: Output<PnsCredentialsArgs>? = null

    private var provisioningState: Output<Either<String, OperationProvisioningState>>? = null

    private var publicNetworkAccess: Output<Either<String, PublicNetworkAccess>>? = null

    private var replicationRegion: Output<Either<String, ReplicationRegion>>? = null

    private var scaleUnit: Output<String>? = null

    private var status: Output<Either<String, NamespaceStatus>>? = null

    private var zoneRedundancy: Output<Either<String, ZoneRedundancyPreference>>? = null

    /**
     * @param value Deprecated.
     */
    @JvmName("polyebuubummqtvk")
    public suspend fun dataCenter(`value`: Output<String>) {
        this.dataCenter = value
    }

    /**
     * @param value Defines values for NamespaceType.
     */
    @JvmName("oloyfdyyplyeacrg")
    public suspend fun namespaceType(`value`: Output<Either<String, NamespaceType>>) {
        this.namespaceType = value
    }

    /**
     * @param value A collection of network authorization rules.
     */
    @JvmName("cfcafdkslwsmygjx")
    public suspend fun networkAcls(`value`: Output<NetworkAclsArgs>) {
        this.networkAcls = value
    }

    /**
     * @param value Collection of Notification Hub or Notification Hub Namespace PNS credentials.
     */
    @JvmName("rvivrdnmuhhbalpl")
    public suspend fun pnsCredentials(`value`: Output<PnsCredentialsArgs>) {
        this.pnsCredentials = value
    }

    /**
     * @param value Defines values for OperationProvisioningState.
     */
    @JvmName("esmmsjheptevhdlf")
    public suspend
    fun provisioningState(`value`: Output<Either<String, OperationProvisioningState>>) {
        this.provisioningState = value
    }

    /**
     * @param value Type of public network access.
     */
    @JvmName("vwmleylbfnmtfued")
    public suspend fun publicNetworkAccess(`value`: Output<Either<String, PublicNetworkAccess>>) {
        this.publicNetworkAccess = value
    }

    /**
     * @param value Allowed replication region
     */
    @JvmName("qrckybunaufrfpat")
    public suspend fun replicationRegion(`value`: Output<Either<String, ReplicationRegion>>) {
        this.replicationRegion = value
    }

    /**
     * @param value Gets or sets scaleUnit where the namespace gets created
     */
    @JvmName("wbnrvffuosacpsnu")
    public suspend fun scaleUnit(`value`: Output<String>) {
        this.scaleUnit = value
    }

    /**
     * @param value Namespace status.
     */
    @JvmName("odkbwipqqivecadx")
    public suspend fun status(`value`: Output<Either<String, NamespaceStatus>>) {
        this.status = value
    }

    /**
     * @param value Namespace SKU name.
     */
    @JvmName("qxnajjnkpmhgvlqr")
    public suspend fun zoneRedundancy(`value`: Output<Either<String, ZoneRedundancyPreference>>) {
        this.zoneRedundancy = value
    }

    /**
     * @param value Deprecated.
     */
    @JvmName("amjwaibpseuareya")
    public suspend fun dataCenter(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataCenter = mapped
    }

    /**
     * @param value Defines values for NamespaceType.
     */
    @JvmName("lowyfghrjvksskso")
    public suspend fun namespaceType(`value`: Either<String, NamespaceType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.namespaceType = mapped
    }

    /**
     * @param value Defines values for NamespaceType.
     */
    @JvmName("vxbjiftudnqtsjub")
    public fun namespaceType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, NamespaceType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.namespaceType = mapped
    }

    /**
     * @param value Defines values for NamespaceType.
     */
    @JvmName("jvblgosgaujafyde")
    public fun namespaceType(`value`: NamespaceType) {
        val toBeMapped = Either.ofRight<String, NamespaceType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.namespaceType = mapped
    }

    /**
     * @param value A collection of network authorization rules.
     */
    @JvmName("fdxlgbbecsndymxa")
    public suspend fun networkAcls(`value`: NetworkAclsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.networkAcls = mapped
    }

    /**
     * @param argument A collection of network authorization rules.
     */
    @JvmName("dqriabyxntjkdtgo")
    public suspend fun networkAcls(argument: suspend NetworkAclsArgsBuilder.() -> Unit) {
        val toBeMapped = NetworkAclsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.networkAcls = mapped
    }

    /**
     * @param value Collection of Notification Hub or Notification Hub Namespace PNS credentials.
     */
    @JvmName("reaecfploelypxoa")
    public suspend fun pnsCredentials(`value`: PnsCredentialsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.pnsCredentials = mapped
    }

    /**
     * @param argument Collection of Notification Hub or Notification Hub Namespace PNS credentials.
     */
    @JvmName("avwwivkkdpbyfkjn")
    public suspend fun pnsCredentials(argument: suspend PnsCredentialsArgsBuilder.() -> Unit) {
        val toBeMapped = PnsCredentialsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.pnsCredentials = mapped
    }

    /**
     * @param value Defines values for OperationProvisioningState.
     */
    @JvmName("ptvitukmltqvsqul")
    public suspend fun provisioningState(`value`: Either<String, OperationProvisioningState>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.provisioningState = mapped
    }

    /**
     * @param value Defines values for OperationProvisioningState.
     */
    @JvmName("vyrljrwimqkbtypp")
    public fun provisioningState(`value`: String) {
        val toBeMapped = Either.ofLeft<String, OperationProvisioningState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.provisioningState = mapped
    }

    /**
     * @param value Defines values for OperationProvisioningState.
     */
    @JvmName("aufmplrmvjrakcte")
    public fun provisioningState(`value`: OperationProvisioningState) {
        val toBeMapped = Either.ofRight<String, OperationProvisioningState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.provisioningState = mapped
    }

    /**
     * @param value Type of public network access.
     */
    @JvmName("dqtwyqbydhilyxim")
    public suspend fun publicNetworkAccess(`value`: Either<String, PublicNetworkAccess>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publicNetworkAccess = mapped
    }

    /**
     * @param value Type of public network access.
     */
    @JvmName("osombhsduquuyifi")
    public fun publicNetworkAccess(`value`: String) {
        val toBeMapped = Either.ofLeft<String, PublicNetworkAccess>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.publicNetworkAccess = mapped
    }

    /**
     * @param value Type of public network access.
     */
    @JvmName("wpwnutdctvhfwawh")
    public fun publicNetworkAccess(`value`: PublicNetworkAccess) {
        val toBeMapped = Either.ofRight<String, PublicNetworkAccess>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.publicNetworkAccess = mapped
    }

    /**
     * @param value Allowed replication region
     */
    @JvmName("liwopvgbhkllsksf")
    public suspend fun replicationRegion(`value`: Either<String, ReplicationRegion>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.replicationRegion = mapped
    }

    /**
     * @param value Allowed replication region
     */
    @JvmName("rsiivroaitlkkagf")
    public fun replicationRegion(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ReplicationRegion>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.replicationRegion = mapped
    }

    /**
     * @param value Allowed replication region
     */
    @JvmName("qdvaiuxhuintxxsi")
    public fun replicationRegion(`value`: ReplicationRegion) {
        val toBeMapped = Either.ofRight<String, ReplicationRegion>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.replicationRegion = mapped
    }

    /**
     * @param value Gets or sets scaleUnit where the namespace gets created
     */
    @JvmName("byhmsyuyvudmtkuc")
    public suspend fun scaleUnit(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scaleUnit = mapped
    }

    /**
     * @param value Namespace status.
     */
    @JvmName("qafdrmiqoelxjycx")
    public suspend fun status(`value`: Either<String, NamespaceStatus>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value Namespace status.
     */
    @JvmName("mvffprajvbjodjeq")
    public fun status(`value`: String) {
        val toBeMapped = Either.ofLeft<String, NamespaceStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value Namespace status.
     */
    @JvmName("rnwcbqrhpgjggvwl")
    public fun status(`value`: NamespaceStatus) {
        val toBeMapped = Either.ofRight<String, NamespaceStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value Namespace SKU name.
     */
    @JvmName("cdqiengaaryhfcjg")
    public suspend fun zoneRedundancy(`value`: Either<String, ZoneRedundancyPreference>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.zoneRedundancy = mapped
    }

    /**
     * @param value Namespace SKU name.
     */
    @JvmName("xsonoarijuxcmdud")
    public fun zoneRedundancy(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ZoneRedundancyPreference>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.zoneRedundancy = mapped
    }

    /**
     * @param value Namespace SKU name.
     */
    @JvmName("mjtbqwtxayudpgvl")
    public fun zoneRedundancy(`value`: ZoneRedundancyPreference) {
        val toBeMapped = Either.ofRight<String, ZoneRedundancyPreference>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.zoneRedundancy = mapped
    }

    internal fun build(): NamespacePropertiesArgs = NamespacePropertiesArgs(
        dataCenter = dataCenter,
        namespaceType = namespaceType,
        networkAcls = networkAcls,
        pnsCredentials = pnsCredentials,
        provisioningState = provisioningState,
        publicNetworkAccess = publicNetworkAccess,
        replicationRegion = replicationRegion,
        scaleUnit = scaleUnit,
        status = status,
        zoneRedundancy = zoneRedundancy,
    )
}

==> pulumi-azure-native-kotlin-2.37.0.0-sources.jar: com/pulumi/azurenative/notificationhubs/kotlin/inputs/NamespacePropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.notificationhubs.kotlin.inputs

import com.pulumi.azurenative.notificationhubs.inputs.NamespacePropertiesArgs.builder
import com.pulumi.azurenative.notificationhubs.kotlin.enums.NamespaceStatus
import com.pulumi.azurenative.notificationhubs.kotlin.enums.NamespaceType
import com.pulumi.azurenative.notificationhubs.kotlin.enums.OperationProvisioningState
import com.pulumi.azurenative.notificationhubs.kotlin.enums.PublicNetworkAccess
import com.pulumi.azurenative.notificationhubs.kotlin.enums.ReplicationRegion
import com.pulumi.azurenative.notificationhubs.kotlin.enums.ZoneRedundancyPreference
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Represents namespace properties.
 * @property dataCenter Deprecated.
 * @property namespaceType Defines values for NamespaceType.
 * @property networkAcls A collection of network authorization rules.
 * @property pnsCredentials Collection of Notification Hub or Notification Hub Namespace PNS credentials.
 * @property provisioningState Defines values for OperationProvisioningState.
 * @property publicNetworkAccess Type of public network access.
 * @property replicationRegion Allowed replication region
 * @property scaleUnit Gets or sets scaleUnit where the namespace gets created
 * @property status Namespace status.
 * @property zoneRedundancy Namespace SKU name.
 */
public data class NamespacePropertiesArgs(
    public val dataCenter: Output<String>? = null,
    public val namespaceType: Output<Either<String, NamespaceType>>? = null,
    public val networkAcls: Output<NetworkAclsArgs>? = null,
    public val pnsCredentials: Output<PnsCredentialsArgs>? = null,
    public val provisioningState: Output<Either<String, OperationProvisioningState>>? = null,
    public val publicNetworkAccess: Output<Either<String, PublicNetworkAccess>>? = null,
    public val replicationRegion: Output<Either<String, ReplicationRegion>>? = null,
    public val scaleUnit: Output<String>? = null,
    public val status: Output<Either<String, NamespaceStatus>>? = null,
    public val zoneRedundancy: Output<Either<String, ZoneRedundancyPreference>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.notificationhubs.inputs.NamespacePropertiesArgs> {
    override fun toJava(): com.pulumi.azurenative.notificationhubs.inputs.NamespacePropertiesArgs =
        com.pulumi.azurenative.notificationhubs.inputs.NamespacePropertiesArgs.builder()
            .dataCenter(dataCenter?.applyValue({ args0 -> args0 }))
            .namespaceType(
                namespaceType?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .networkAcls(networkAcls?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .pnsCredentials(pnsCredentials?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .provisioningState(
                provisioningState?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .publicNetworkAccess(
                publicNetworkAccess?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .replicationRegion(
                replicationRegion?.applyValue({ args0 ->
                    args0.transform(
                        { args0 -> args0 },
                        { args0 -> args0.let({ args0 -> args0.toJava() }) },
                    )
                }),
            )
            .scaleUnit(scaleUnit?.applyValue({ args0 -> args0 }))
            .status(
                status?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            )
            .zoneRedundancy(
                zoneRedundancy?.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 -> args0.toJava() })
                    })
                }),
            ).build()
}

/**
 * Builder for [NamespacePropertiesArgs].
 */
@PulumiTagMarker
public class NamespacePropertiesArgsBuilder internal constructor() {
    private var dataCenter: Output<String>? = null

    private var namespaceType: Output<Either<String, NamespaceType>>? = null

    private var networkAcls: Output<NetworkAclsArgs>? = null

    private var pnsCredentials: Output<PnsCredentialsArgs>? = null

    private var provisioningState: Output<Either<String, OperationProvisioningState>>? = null

    private var publicNetworkAccess: Output<Either<String, PublicNetworkAccess>>? = null

    private var replicationRegion: Output<Either<String, ReplicationRegion>>? = null

    private var scaleUnit: Output<String>? = null

    private var status: Output<Either<String, NamespaceStatus>>? = null

    private var zoneRedundancy: Output<Either<String, ZoneRedundancyPreference>>? = null

    /**
     * @param value Deprecated.
     */
    @JvmName("cykoohppxodppuxh")
    public suspend fun dataCenter(`value`: Output<String>) {
        this.dataCenter = value
    }

    /**
     * @param value Defines values for NamespaceType.
     */
    @JvmName("rmfaqokhsumpuwoi")
    public suspend fun namespaceType(`value`: Output<Either<String, NamespaceType>>) {
        this.namespaceType = value
    }

    /**
     * @param value A collection of network authorization rules.
     */
    @JvmName("vjgcwgltmlknceay")
    public suspend fun networkAcls(`value`: Output<NetworkAclsArgs>) {
        this.networkAcls = value
    }

    /**
     * @param value Collection of Notification Hub or Notification Hub Namespace PNS credentials.
     */
    @JvmName("jxkjrimiijbpveuk")
    public suspend fun pnsCredentials(`value`: Output<PnsCredentialsArgs>) {
        this.pnsCredentials = value
    }

    /**
     * @param value Defines values for OperationProvisioningState.
     */
    @JvmName("lhfjiofqepjrvnln")
    public suspend
    fun provisioningState(`value`: Output<Either<String, OperationProvisioningState>>) {
        this.provisioningState = value
    }

    /**
     * @param value Type of public network access.
     */
    @JvmName("smwosxlmuejxfrdq")
    public suspend fun publicNetworkAccess(`value`: Output<Either<String, PublicNetworkAccess>>) {
        this.publicNetworkAccess = value
    }

    /**
     * @param value Allowed replication region
     */
    @JvmName("imhlernnctbfewle")
    public suspend fun replicationRegion(`value`: Output<Either<String, ReplicationRegion>>) {
        this.replicationRegion = value
    }

    /**
     * @param value Gets or sets scaleUnit where the namespace gets created
     */
    @JvmName("rbiyfcurduwllooh")
    public suspend fun scaleUnit(`value`: Output<String>) {
        this.scaleUnit = value
    }

    /**
     * @param value Namespace status.
     */
    @JvmName("ejpwdmalttgfycja")
    public suspend fun status(`value`: Output<Either<String, NamespaceStatus>>) {
        this.status = value
    }

    /**
     * @param value Namespace SKU name.
     */
    @JvmName("fixctqtmlaxwyavi")
    public suspend fun zoneRedundancy(`value`: Output<Either<String, ZoneRedundancyPreference>>) {
        this.zoneRedundancy = value
    }

    /**
     * @param value Deprecated.
     */
    @JvmName("etexqxavnfjjamui")
    public suspend fun dataCenter(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.dataCenter = mapped
    }

    /**
     * @param value Defines values for NamespaceType.
     */
    @JvmName("gnwygxfxoclxqwps")
    public suspend fun namespaceType(`value`: Either<String, NamespaceType>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.namespaceType = mapped
    }

    /**
     * @param value Defines values for NamespaceType.
     */
    @JvmName("ionmwvubuyfbvalo")
    public fun namespaceType(`value`: String) {
        val toBeMapped = Either.ofLeft<String, NamespaceType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.namespaceType = mapped
    }

    /**
     * @param value Defines values for NamespaceType.
     */
    @JvmName("epowkvddwmoodjrt")
    public fun namespaceType(`value`: NamespaceType) {
        val toBeMapped = Either.ofRight<String, NamespaceType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.namespaceType = mapped
    }

    /**
     * @param value A collection of network authorization rules.
     */
    @JvmName("jrywbsqvnxioaofr")
    public suspend fun networkAcls(`value`: NetworkAclsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.networkAcls = mapped
    }

    /**
     * @param argument A collection of network authorization rules.
     */
    @JvmName("lrcneexigkgrnclo")
    public suspend fun networkAcls(argument: suspend NetworkAclsArgsBuilder.() -> Unit) {
        val toBeMapped = NetworkAclsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.networkAcls = mapped
    }

    /**
     * @param value Collection of Notification Hub or Notification Hub Namespace PNS credentials.
     */
    @JvmName("eywrkgykgotpxtlk")
    public suspend fun pnsCredentials(`value`: PnsCredentialsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.pnsCredentials = mapped
    }

    /**
     * @param argument Collection of Notification Hub or Notification Hub Namespace PNS credentials.
     */
    @JvmName("dltsqpnmibhwmjgx")
    public suspend fun pnsCredentials(argument: suspend PnsCredentialsArgsBuilder.() -> Unit) {
        val toBeMapped = PnsCredentialsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.pnsCredentials = mapped
    }

    /**
     * @param value Defines values for OperationProvisioningState.
     */
    @JvmName("gyoytseenuuefcqn")
    public suspend fun provisioningState(`value`: Either<String, OperationProvisioningState>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.provisioningState = mapped
    }

    /**
     * @param value Defines values for OperationProvisioningState.
     */
    @JvmName("hpqwpnwbelruwcyu")
    public fun provisioningState(`value`: String) {
        val toBeMapped = Either.ofLeft<String, OperationProvisioningState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.provisioningState = mapped
    }

    /**
     * @param value Defines values for OperationProvisioningState.
     */
    @JvmName("qsminigdxlfdfolq")
    public fun provisioningState(`value`: OperationProvisioningState) {
        val toBeMapped = Either.ofRight<String, OperationProvisioningState>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.provisioningState = mapped
    }

    /**
     * @param value Type of public network access.
     */
    @JvmName("addhwdhanhoggcui")
    public suspend fun publicNetworkAccess(`value`: Either<String, PublicNetworkAccess>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.publicNetworkAccess = mapped
    }

    /**
     * @param value Type of public network access.
     */
    @JvmName("yypgecnslutftsgj")
    public fun publicNetworkAccess(`value`: String) {
        val toBeMapped = Either.ofLeft<String, PublicNetworkAccess>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.publicNetworkAccess = mapped
    }

    /**
     * @param value Type of public network access.
     */
    @JvmName("afxetsofgwrtecgf")
    public fun publicNetworkAccess(`value`: PublicNetworkAccess) {
        val toBeMapped = Either.ofRight<String, PublicNetworkAccess>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.publicNetworkAccess = mapped
    }

    /**
     * @param value Allowed replication region
     */
    @JvmName("grcadcefjjwrteeb")
    public suspend fun replicationRegion(`value`: Either<String, ReplicationRegion>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.replicationRegion = mapped
    }

    /**
     * @param value Allowed replication region
     */
    @JvmName("hmkubovckbwwacgx")
    public fun replicationRegion(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ReplicationRegion>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.replicationRegion = mapped
    }

    /**
     * @param value Allowed replication region
     */
    @JvmName("laeofcmvmknueduo")
    public fun replicationRegion(`value`: ReplicationRegion) {
        val toBeMapped = Either.ofRight<String, ReplicationRegion>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.replicationRegion = mapped
    }

    /**
     * @param value Gets or sets scaleUnit where the namespace gets created
     */
    @JvmName("ajsvxbrohymbnpjy")
    public suspend fun scaleUnit(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scaleUnit = mapped
    }

    /**
     * @param value Namespace status.
     */
    @JvmName("qgxgdeuotuvseufv")
    public suspend fun status(`value`: Either<String, NamespaceStatus>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value Namespace status.
     */
    @JvmName("fqoqjpaqrvfgrlgv")
    public fun status(`value`: String) {
        val toBeMapped = Either.ofLeft<String, NamespaceStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value Namespace status.
     */
    @JvmName("ucbbwncsvqqsqvge")
    public fun status(`value`: NamespaceStatus) {
        val toBeMapped = Either.ofRight<String, NamespaceStatus>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.status = mapped
    }

    /**
     * @param value Namespace SKU name.
     */
    @JvmName("hawdcuriawijopyh")
    public suspend fun zoneRedundancy(`value`: Either<String, ZoneRedundancyPreference>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.zoneRedundancy = mapped
    }

    /**
     * @param value Namespace SKU name.
     */
    @JvmName("fjefulfnlsdbftra")
    public fun zoneRedundancy(`value`: String) {
        val toBeMapped = Either.ofLeft<String, ZoneRedundancyPreference>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.zoneRedundancy = mapped
    }

    /**
     * @param value Namespace SKU name.
     */
    @JvmName("jymvogeycaojijtg")
    public fun zoneRedundancy(`value`: ZoneRedundancyPreference) {
        val toBeMapped = Either.ofRight<String, ZoneRedundancyPreference>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.zoneRedundancy = mapped
    }

    internal fun build(): NamespacePropertiesArgs = NamespacePropertiesArgs(
        dataCenter = dataCenter,
        namespaceType = namespaceType,
        networkAcls = networkAcls,
        pnsCredentials = pnsCredentials,
        provisioningState = provisioningState,
        publicNetworkAccess = publicNetworkAccess,
        replicationRegion = replicationRegion,
        scaleUnit = scaleUnit,
        status = status,
        zoneRedundancy = zoneRedundancy,
    )
}
